==> kvpnc_0.8.6.1.orig.tar.gz: kvpnc-0.8.6.1.orig/src/openvpnmanagementhandler.h <==
/***************************************************************************
*   Copyright (C) 2004 by Christoph Thielecke                             *
*   crissi99@gmx.de                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef OPENVPNMANAGEMENTHANDLER_H
#define OPENVPNMANAGEMENTHANDLER_H

#include <stdlib.h>
#include <qsocket.h>
#include "kvpncconfig.h"


class QSocket;

/**
	@author Christoph Thielecke <crissi99@gmx.de>
*/
class OpenvpnManagementHandler : public QObject {
		Q_OBJECT
	public:
		OpenvpnManagementHandler(QObject *parent, KVpncConfig *GlobalConfig );
		~OpenvpnManagementHandler();
		void closeConnection();

	private slots:
		void socketConnected();
		void socketConnectionClosed();
		void socketError( int );
		void socketReadyRead();
		void socketClosed();

	public slots:
		void sendToServer(QString cmd);

	private:
		KVpncConfig *GlobalConfig;
		bool fInHold;
		QSocket *socket;
	signals:
		void terminate_openvpn();

};
#endif

==> kvpnc_0.8.9.orig.tar.gz: kvpnc-0.8.9.orig/src/openvpnmanagementhandler.h <==
/***************************************************************************
*   Copyright (C) 2004 by Christoph Thielecke                             *
*   crissi99@gmx.de                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef OPENVPNMANAGEMENTHANDLER_H
#define OPENVPNMANAGEMENTHANDLER_H

#include <stdlib.h>
#include <qsocket.h>
#include "kvpncconfig.h"


class QSocket;

/**
	@author Christoph Thielecke <crissi99@gmx.de>
*/
class OpenvpnManagementHandler : public QObject {
		Q_OBJECT
	public:
		OpenvpnManagementHandler(QObject *parent, KVpncConfig *GlobalConfig );
		~OpenvpnManagementHandler();
		void closeConnection();
		bool isConnectedToManagementPort();
		bool doConnect();

	protected slots:
		void socketConnected();
		void socketConnectionClosed();
		void socketError( int );
		void socketReadyRead();
		void socketClosed();
		void hostFound();

	public slots:
		void sendToServer(QString cmd);

	private:
		KVpncConfig *GlobalConfig;
		bool fInHold;
		bool connectedToManagementPort;
		QSocket *socket;
		QString errormsg;
	signals:
		void terminate_openvpn();

};
#endif
